@@ -32,7 +32,6 @@
 
 class QSpinBox;
 
-class KComboBox;
 class KJob;
 namespace KIO {
   class StoredTransferJob;
@@ -71,8 +70,7 @@ public:
    */
   virtual QString source() const Q_DECL_OVERRIDE;
   virtual bool isSearching() const Q_DECL_OVERRIDE { return m_started; }
-  // only search title, person, isbn, or keyword. No Raw for now.
-  virtual bool canSearch(FetchKey k) const Q_DECL_OVERRIDE { return k == Title || k == Person || k == ISBN || k == Keyword || k == LCCN; }
+  virtual bool canSearch(FetchKey k) const Q_DECL_OVERRIDE;
   virtual void stop() Q_DECL_OVERRIDE;
   virtual Data::EntryPtr fetchEntryHook(uint uid) Q_DECL_OVERRIDE;
   virtual Type type() const Q_DECL_OVERRIDE { return SRU; }
