@@ -1061,7 +1061,7 @@ void MainWindow::saveCollectionOptions(Tellico::Data::CollPtr coll_) {
     if(m_entryGrouping->currentText() == (QLatin1Char('<') + i18n("People") + QLatin1Char('>'))) {
       groupName = Data::Collection::s_peopleGroupName;
     } else {
-      groupName = Kernel::self()->fieldNameByTitle(m_entryGrouping->currentText());
+      groupName = Data::Document::self()->collection()->fieldNameByTitle(m_entryGrouping->currentText());
     }
     if(coll_->type() != Data::Collection::Base) {
       config.writeEntry("Group By", groupName);
@@ -1667,7 +1667,7 @@ void MainWindow::slotUpdateCollectionToolBar(Tellico::Data::CollPtr coll_) {
 void MainWindow::slotChangeGrouping() {
   const QString title = m_entryGrouping->currentText();
 
-  QString groupName = Kernel::self()->fieldNameByTitle(title);
+  QString groupName = Data::Document::self()->collection()->fieldNameByTitle(title);
   if(groupName.isEmpty()) {
     if(title == (QLatin1Char('<') + i18n("People") + QLatin1Char('>'))) {
       groupName = Data::Collection::s_peopleGroupName;
