@@ -36,7 +36,6 @@ class QUndoCommand;
 class QUrl;
 
 namespace Tellico {
-  class MainWindow;
   class Filter;
   namespace Data {
     class Collection;
@@ -52,7 +51,7 @@ public:
   /**
    * Initializes the singleton. Should just be called once, from Tellico::MainWindow
    */
-  static void init(MainWindow* parent) { if(!s_self) s_self = new Kernel(parent); }
+  static void init(QWidget* parent) { if(!s_self) s_self = new Kernel(parent); }
 
   /**
    * Returns a pointer to the parent widget. This is mainly used for error dialogs and the like.
@@ -67,27 +66,6 @@ public:
    * @return The URL
    */
   QUrl URL() const;
-  /**
-   * Returns a list of the field titles, wraps the call to the collection itself.
-   *
-   * @return the field titles
-   */
-  QStringList fieldTitles() const;
-  /**
-   * Returns the name of an field, given its title. Wraps the call to the collection itself.
-   *
-   * @param title The field title
-   * @return The field name
-   */
-  QString fieldNameByTitle(const QString& title) const;
-  /**
-   * Returns the title of an field, given its name. Wraps the call to the collection itself.
-   *
-   * @param name The field name
-   * @return The field title
-   */
-  QString fieldTitleByName(const QString& name) const;
-  QStringList valuesByFieldName(const QString& name) const;
 
   int collectionType() const;
   QString collectionTypeName() const;
@@ -131,9 +109,8 @@ private:
   static Kernel* s_self;
 
   // all constructors are private
-  Kernel(MainWindow* parent);
-  Kernel(const Kernel&);
-  Kernel& operator=(const Kernel&);
+  Kernel(QWidget* parent);
+  Q_DISABLE_COPY(Kernel);
   ~Kernel();
 
   void doCommand(QUndoCommand* command);
