@@ -56,6 +56,8 @@ private Q_SLOTS:
   void testBug418067();
   void testNoCreationDate();
   void testFutureVersion();
+  void testRelativeLink();
+  void testEmptyFirstTableRow();
 
 private:
   QList<Tellico::Data::CollPtr> m_collections;
